==> kvpnc_0.8.2.1.orig.tar.gz: kvpnc-0.8.2.1.orig/src/profileopenvpnoptions.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROFILEOPENVPNOPTIONS_H
#define PROFILEOPENVPNOPTIONS_H

#include "profileopenvpnoptionsbase.h"
#include <qwidget.h>

/**
@author Christoph Thielecke
*/
class ProfileOpenvpnOptions : public ProfileOpenvpnOptionsBase
{
public:
	ProfileOpenvpnOptions(QWidget *parent);

	~ProfileOpenvpnOptions();

public slots:
    void userdefinedPortToggled(bool);
    virtual void useNsCertTypeToggled(bool);
};

#endif

==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/profileopenvpnoptions.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROFILEOPENVPNOPTIONS_H
#define PROFILEOPENVPNOPTIONS_H

#include "profileopenvpnoptionsbase.h"
#include <qwidget.h>

/**
@author Christoph Thielecke
*/
class ProfileOpenvpnOptions : public ProfileOpenvpnOptionsBase
{
public:
	ProfileOpenvpnOptions(QWidget *parent);

	~ProfileOpenvpnOptions();

public slots:
    void userdefinedPortToggled(bool);
    void useNsCertTypeToggled(bool);
    void useUserdefiniedCipherToggled(bool);
    void useHttpProxyToggeled(bool);
    void useTlsAuthToggled(bool);
    void useTlsRemoteHostToggled(bool);
    void userdefinedRemotePortToggled(bool);
    void userdefiniedPacketSizeToggled(bool);
    void userdefiniedFragmentationSizeToggled(bool);
};

#endif
